@@ -1,4 +1,7 @@
 from pyspark.sql.types import *
+import string
+import re
+from datetime import datetime
 
 
 def handle_pyspark_timestamp_in_schema(pyspark_schema: StructType) -> StructType:
@@ -37,3 +40,20 @@ def handle_pyspark_timestamp_in_schema(pyspark_schema: StructType) -> StructType
             if field_format in ("date-time", "date"):
                 field.dataType = TimestampType()
     return pyspark_schema
+
+
+def import_from_custom_package(package_name, variable):
+    # importing variable from custom package
+    return getattr(__import__(package_name), variable)
+
+
+def import_table_current_step_params(params, table, current_step):
+    # importing table current step params from database params
+    return params[table][current_step]
+
+
+def handle_execution_date_args(dt: str):
+    match = re.search(r"(?<=\.).+?(?=\:)", dt)
+    if match:
+        dt = dt.replace(f".{match.group()[:-3]}", "")
+    return datetime.strptime("".join(dt.rsplit(":", 1)), "%Y-%m-%dT%H:%M:%S%z")
